setStringList method

Future<bool> setStringList(
  1. String key,
  2. List<String> value
)

Saves a list of strings value to persistent storage in the background.

Returns false if the platform implementation can definitively determine that storing the preference failed. A return value of true indicates either that the value was written successfully, or that the underlying platform API does not report success or failure.

Implementation

Future<bool> setStringList(String key, List<String> value) => _setValue('StringList', key, value);